pub struct Me {
pub username: String,
pub public_key: String,
pub private_key: String,
pub context_id: String,
pub verbs: Verbs,
pub conn: Connection,
}Expand description
Represents a local encrypted identity used in dApps or Web3 environments.
Fields
username: Stringpublic_key: Stringprivate_key: Stringcontext_id: Stringverbs: Verbsconn: ConnectionImplementations
Sourceimpl Me
impl Me
Sourcepub fn change_password(
&mut self,
_old_password: &str,
new_password: &str,
) -> Result<(), MeError>
pub fn change_password( &mut self, _old_password: &str, new_password: &str, ) -> Result<(), MeError>
Changes the encryption hash of the private key.
Sourcepub fn display(&self) -> Result<String, MeError>
pub fn display(&self) -> Result<String, MeError>
Returns a pretty-printed JSON representation of the Me struct.
Sourcepub fn load(username: &str, password: &str) -> Result<Self, MeError>
pub fn load(username: &str, password: &str) -> Result<Self, MeError>
Loads an existing Me instance from the local database using username and password.
Sourcepub fn new(username: &str, password: &str) -> Result<(Self, bool), MeError>
pub fn new(username: &str, password: &str) -> Result<(Self, bool), MeError>
Initializes a new Me instance with the given username and password.
pub fn be( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn do_( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn have( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn at( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn relate( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn react( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn communicate( &mut self, context_id: &str, key: &str, value: &str, ) -> Result<(), MeError>
pub fn get( &self, verb: &str, context_id: Option<&str>, key: Option<&str>, value: Option<&str>, json_path: Option<&str>, limit: Option<usize>, offset: Option<usize>, since: Option<&str>, until: Option<&str>, ) -> Result<Vec<(String, String, String, String)>, MeError>